pub unsafe extern "C" fn SzConfigMgr_clearLastException()Expand description
@brief This function clears the last exception thrown in SzConfigMgr
pub unsafe extern "C" fn SzConfigMgr_clearLastException()@brief This function clears the last exception thrown in SzConfigMgr