SzConfigMgr_destroy

Function SzConfigMgr_destroy 

pub unsafe extern "C" fn SzConfigMgr_destroy() -> i64
@brief This method will destroy and perform cleanup for the Sz Config object. It should be called after all other calls are complete.