pub unsafe extern "C" fn SzConfig_clearLastException()Expand description
@brief This function clears the last exception thrown in SzConfig
pub unsafe extern "C" fn SzConfig_clearLastException()@brief This function clears the last exception thrown in SzConfig