SzConfig_init

Function SzConfig_init 

pub unsafe extern "C" fn SzConfig_init(
    moduleName: *const c_char,
    iniParams: *const c_char,
    verboseLogging: i64,
) -> i64
@brief This method will initialize the SzConfig object. It must be called prior to any other calls.

@param moduleName A name for the engine node, to help identify it within system logs. @param iniParams A JSON string containing configuration parameters. @param verboseLogging A flag to enable deeper logging of the Sz processing