SzConfig_load

Function SzConfig_load 

pub unsafe extern "C" fn SzConfig_load(
    jsonConfig: *const c_char,
    configHandle: *mut *mut c_void,
) -> i64
@brief This method initializes the SzConfig object from a JSON string. Any time you need to edit an existing config from an existing repository you will want to use this method to be able to modify it.