pub unsafe extern "C" fn SzDiagnostic_clearLastException()Expand description
@brief This function clears the last exception thrown in SzDiagnostic
pub unsafe extern "C" fn SzDiagnostic_clearLastException()@brief This function clears the last exception thrown in SzDiagnostic