SzDiagnostic_destroy

Function SzDiagnostic_destroy 

pub unsafe extern "C" fn SzDiagnostic_destroy() -> i64
@brief This method will destroy and perform cleanup for the Sz diagnostic object. It should be called after all other calls are complete.