SzDiagnostic_init

Function SzDiagnostic_init 

pub unsafe extern "C" fn SzDiagnostic_init(
    moduleName: *const c_char,
    iniParams: *const c_char,
    verboseLogging: i64,
) -> i64
@brief This method will initialize the Sz diagnostic object. It must be called prior to any other calls.

@param moduleName A name for the diagnostic node, to help identify it within system logs. @param iniParams A JSON string specifying the configuration parameters @param verboseLogging A flag to enable deeper logging of the Sz processing