pub unsafe extern "C" fn SzProduct_clearLastException()Expand description
@brief This function clears the last exception thrown in SzProduct
pub unsafe extern "C" fn SzProduct_clearLastException()@brief This function clears the last exception thrown in SzProduct