SzProduct_destroy

Function SzProduct_destroy 

pub unsafe extern "C" fn SzProduct_destroy() -> i64
@brief This method will destroy and perform cleanup for the Sz product object. It should be called after all other calls are complete.