SzProduct_getLicense

Function SzProduct_getLicense 

pub unsafe extern "C" fn SzProduct_getLicense() -> *mut c_char
@brief This function is used to return the license information

@return Returns a pointer to the license information in JSON format