pub unsafe extern "C" fn SzProduct_init(
moduleName: *const c_char,
iniParams: *const c_char,
verboseLogging: i64,
) -> i64Expand description
@brief This method will initialize the Sz product object. It must be called prior to any other calls.
@param moduleName A name for the node, to help identify it within system logs. @param iniParams A JSON string specifying the configuration parameters @param verboseLogging A flag to enable deeper logging of the Sz processing