SzProduct_validateLicenseFile

Function SzProduct_validateLicenseFile 

pub unsafe extern "C" fn SzProduct_validateLicenseFile(
    licenseFilePath: *const c_char,
    errorBuf: *mut *mut c_char,
    errorBufSize: *mut usize,
    resizeFunc: Option<unsafe extern "C" fn(ptr: *mut c_void, newSize: usize) -> *mut c_void>,
) -> i64
@brief This function is used to validate an external license file for validity. If it is not valid, information on why will be returned through the error buffer parameters.

These functions do not require SzProduct to be initialized.

@param licenseFilePath The file path and name of the file to validate. @param errorBuf The buffer to write an error message to @param errorBufSize The size of the error buffer @param resizeFunc A function to resize the error buffer, if it needs more space.

@return 0 if the file is a valid license.