pub unsafe extern "C" fn Sz_deleteRecord(
dataSourceCode: *const c_char,
recordID: *const c_char,
) -> i64Expand description
@brief This method is used to delete observation data from the system. This removes a single entity observation record, by removing all of its feature data and the observation itself.
@param dataSourceCode The data source for the observation. @param recordID The ID for the record @param responseBuf A buffer that returns a JSON object that summaries the changes cased by adding the record. Also contains the recordID. @param bufSize The size of the responseBuf buffer @param resizeFunc A function pointer that can be used to resize the memory buffer specified in the responseBuf argument. This function will be called to allocate more memory if the response buffer is not large enough. This argument may be NULL. If it is NULL, the function will return an error if the result is larger than the buffer. @return Returns 0 for success. Returns -1 if the response status indicates failure or the Sz module is not initialized. Returns -2 if an exception was thrown and caught.