Sz_destroy

Function Sz_destroy 

pub unsafe extern "C" fn Sz_destroy() -> i64
@brief This method will destroy and perform cleanup for the Sz processing object. It should be called after all other calls are complete.