Sz_exportJSONEntityReport

Function Sz_exportJSONEntityReport 

pub unsafe extern "C" fn Sz_exportJSONEntityReport(
    flags: i64,
    responseHandle: *mut usize,
) -> i64
@brief This is used to export entity data from known entities. This function returns an export-handle that can be read from to get the export data in JSON format. The export-handle should be read using the “Sz_fetchNext” function, and closed when work is complete. Each output row contains the exported entity data for a single resolved entity.

@param flags A bit mask specifying control flags, such as “SZ_EXPORT_INCLUDE_SINGLE_RECORD_ENTITIES”. The default and recommended value is “SZ_EXPORT_DEFAULT_FLAGS”.

@return Returns an export handle that the entity data can be read from.