Sz_fetchNext

Function Sz_fetchNext 

pub unsafe extern "C" fn Sz_fetchNext(
    responseHandle: usize,
    responseBuf: *mut c_char,
    bufSize: usize,
) -> i64
@brief This function is used to read entity data from an export handle, one data row at a time.

@param responseHandle The export handle to retrieve data from @param responseBuf The buffer to write the string data to @param bufSize The size of the response buffer

@return Returns a pointer to the buffer if successful, or -1 otherwise