Sz_findNetworkByEntityID

Function Sz_findNetworkByEntityID 

pub unsafe extern "C" fn Sz_findNetworkByEntityID(
    entityList: *const c_char,
    maxDegree: i64,
    buildOutDegree: i64,
    maxEntities: i64,
    responseBuf: *mut *mut c_char,
    bufSize: *mut usize,
    resizeFunc: Option<unsafe extern "C" fn(ptr: *mut c_void, newSize: usize) -> *mut c_void>,
) -> i64
@brief This method is used to find a network of entity relationships, surrounding the paths between a set of entities.

@param entityList A JSON document identifying the list of entities to find paths between and a network around. (example: {“ENTITIES”:[{“ENTITY_ID”:“6”},{“ENTITY_ID”:“11”},{“ENTITY_ID”:“9”}]} ) @param recordList A JSON document identifying the list of record entities to find paths between and a network around. (example: {“RECORDS”:[{“DATA_SOURCE”:“PEOPLE”,“RECORD_ID”:“1504”},{“DATA_SOURCE”:“PEOPLE”,“RECORD_ID”:“1507”},{“DATA_SOURCE”:“PEOPLE”,“RECORD_ID”:“1510”}]} ) @param maxDegree The maximum degree of relationships to search for a path @param buildOutDegree The maximum degree of relationships to include in the network around each entity @param maxEntities The maximum number of entities to return @param responseBuf A memory buffer for returning the response document. @param bufSize The max number of bytes that can be stored in responseBuf. The response buffer must be able to hold the whole response message, or a resize method must be provided that may be used to resize the buffer. This will return the new size. @param resizeFunc A function pointer that can be used to resize the memory buffer specified in the responseBuf argument. This function will be called to allocate more memory if the response buffer is not large enough. This argument may be NULL. If it is NULL, the function will return an error if the result is larger than the buffer. @return Returns 0 for success. Returns -1 if the response status indicates failure or the Sz module is not initialized. Returns -2 if an exception was thrown and caught.