pub unsafe extern "C" fn Sz_findPathByEntityIDIncludingSource(
entityID1: i64,
entityID2: i64,
maxDegree: i64,
avoidedEntities: *const c_char,
requiredDsrcs: *const c_char,
responseBuf: *mut *mut c_char,
bufSize: *mut usize,
resizeFunc: Option<unsafe extern "C" fn(ptr: *mut c_void, newSize: usize) -> *mut c_void>,
) -> i64Expand description
@brief This method is used to find a relationship path between entities, that avoids a particular set of entities, and also requires at least one data source from a set to be part of the path.
@param entityID1 The starting entity of the relationship path @param entityID2 The ending entity of the relationship path @param dataSourceCode1 The data source for the starting record of the relationship path @param recordID1 The record ID for the starting record of the relationship path @param dataSourceCode2 The data source for the ending record of the relationship path @param recordID2 The record ID for the ending record of the relationship path @param maxDegree The maximum degree of relationships to search @param avoidedEntities A JSON document identifying the list of entities to avoid in the path. (example: {“ENTITIES”:[{“ENTITY_ID”:“6”},{“ENTITY_ID”:“11”},{“ENTITY_ID”:“9”}]} ) @param avoidedRecords A JSON document identifying the list of records for entities to avoid in the path. (example: {“RECORDS”:[{“DATA_SOURCE”:“PEOPLE”,“RECORD_ID”:“1504”},{“DATA_SOURCE”:“PEOPLE”,“RECORD_ID”:“1507”}]} ) @param requiredDsrcs A JSON document identifying the list of data sources to watch for (example: {“DATA_SOURCES”:[“PEOPLE”,“COMPANIES”]} ) @param flags A bit mask specifying control flags, such as “SZ_FIND_PATH_STRICT_AVOID”. The default and recommended value is “SZ_FIND_PATH_DEFAULT_FLAGS”. @param responseBuf A memory buffer for returning the response document. @param bufSize The max number of bytes that can be stored in responseBuf. The response buffer must be able to hold the whole response message, or a resize method must be provided that may be used to resize the buffer. This will return the new size. @param resizeFunc A function pointer that can be used to resize the memory buffer specified in the responseBuf argument. This function will be called to allocate more memory if the response buffer is not large enough. This argument may be NULL. If it is NULL, the function will return an error if the result is larger than the buffer. @return Returns 0 for success. Returns -1 if the response status indicates failure or the Sz module is not initialized. Returns -2 if an exception was thrown and caught.