Sz_getRecordPreview

Function Sz_getRecordPreview 

pub unsafe extern "C" fn Sz_getRecordPreview(
    jsonData: *const c_char,
    flags: i64,
    responseBuf: *mut *mut c_char,
    bufSize: *mut usize,
    resizeFunc: Option<unsafe extern "C" fn(ptr: *mut c_void, newSize: usize) -> *mut c_void>,
) -> i64
@brief This method gives a similar data response to getRecord but you supply the record instead of it being loaded.

@param jsonData A JSON document containing the information to examine @param responseBuf A memory buffer for returning the response document. If an error occurred, an error response is stored here. @param bufSize The max number of bytes that can be stored in responseBuf. The response buffer must be able to hold at least this many bytes, or a resize method must be provided that may be used to resize the buffer. This will return the new size. @param resizeFunc A function pointer that can be used to resize the memory buffer specified in the responseBuf argument. This function will be called to allocate more memory if the response buffer is not large enough. This argument may be NULL. If it is NULL, the function will return an error if the result is larger than the buffer. @return Returns 0 for success. Returns -1 if the response status indicates failure or the Sz module is not initialized. Returns -2 if an exception was thrown and caught.