Sz_getVirtualEntityByRecordID

Function Sz_getVirtualEntityByRecordID 

pub unsafe extern "C" fn Sz_getVirtualEntityByRecordID(
    recordList: *const c_char,
    responseBuf: *mut *mut c_char,
    bufSize: *mut usize,
    resizeFunc: Option<unsafe extern "C" fn(ptr: *mut c_void, newSize: usize) -> *mut c_void>,
) -> i64
@brief This method gives information on how an entity composed of a given set of records would look