Sz_init

Function Sz_init 

pub unsafe extern "C" fn Sz_init(
    moduleName: *const c_char,
    iniParams: *const c_char,
    verboseLogging: i64,
) -> i64
@brief This method will initialize the Sz processing object. It must be called once per process, prior to any other calls.

@param moduleName A name for the processing node, to help identify it within system logs. @param iniParams A JSON string containing configuration parameters. @param initConfigID Identifier for the configuration to use in initialization. @param verboseLogging A flag to enable deeper logging of the Sz processing