Sz_processRedoRecord

Function Sz_processRedoRecord 

pub unsafe extern "C" fn Sz_processRedoRecord(
    redoRecord: *const c_char,
) -> i64
@brief Process a record contained in the internal redo-queue

@param redoRecord Null terminated UT8-JSON record from Sz_getRedoRecord @param infoBuf Same as responseBuf. In a success, returns info about the affected entities @param infoBufSize Same as bufSize but for infoBuf @param resizeFunc A function pointer that can be used to resize the memory buffer specified in the responseBuf argument. This function will be called to allocate more memory if the response buffer is not large enough. This argument may be NULL. If it is NULL, the function will return an error if the result is larger than the buffer.