pub unsafe extern "C" fn SzProduct_getVersion() -> *mut c_charExpand description
@brief This function is used to return the version and build information
This function does not require SzProduct to be initialized.
@return Returns a pointer to the version and build information in JSON format