pub unsafe extern "C" fn Sz_exportCSVEntityReport(
csvColumnList: *const c_char,
flags: i64,
responseHandle: *mut usize,
) -> i64Expand description
@brief This is used to export entity data from known entities. This function returns an export-handle that can be read from to get the export data in CSV format. The export-handle should be read using the “Sz_fetchNext” function, and closed when work is complete. The first output row returned by the export-handle contains the JSON column headers as a string. Each following row contains the exported entity data.
@param flags A bit mask specifying other control flags, such as “SZ_EXPORT_INCLUDE_SINGLE_RECORD_ENTITIES”. The default and recommended value is “SZ_EXPORT_DEFAULT_FLAGS”.
@return Returns an export handle that the entity data can be read from.